==> unit-1.0.25-sources.jar: io/intino/goros/unit/box/rest/resources/PostSaveNodeDocumentResource.java <==
package io.intino.goros.unit.box.rest.resources;

import java.util.List;
import java.util.ArrayList;
import io.intino.alexandria.exceptions.*;
import io.intino.goros.unit.box.*;
import io.intino.alexandria.core.Box;
import io.intino.alexandria.rest.*;
import io.intino.alexandria.http.spark.SparkManager;
import io.intino.alexandria.http.spark.SparkPushService;



public class PostSaveNodeDocumentResource implements Resource {

	private UnitBox box;
	private SparkManager<SparkPushService> manager;

	public PostSaveNodeDocumentResource(UnitBox box, SparkManager manager) {
		this.box = box;
		this.manager = manager;
	}

	public void execute() throws AlexandriaException {
		write(fill(new io.intino.goros.unit.box.actions.PostSaveNodeDocumentAction()).execute());
	}

	private io.intino.goros.unit.box.actions.PostSaveNodeDocumentAction fill(io.intino.goros.unit.box.actions.PostSaveNodeDocumentAction action) {
		action.box = this.box;
		action.context = context();
		action.id = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("id"), String.class);
		action.data = manager.fromForm("data");
		action.contenttype = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("contenttype"), String.class);
		return action;
	}

	private void write(String object) {
		manager.write(io.intino.alexandria.rest.ResponseAdapter.adapt(object));
	}

	private io.intino.alexandria.http.spark.SparkContext context() {
		io.intino.alexandria.http.spark.SparkContext context = new io.intino.alexandria.http.spark.SparkContext(manager);

		context.put("ip", manager.ip());
		return context;
	}
}

==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/rest/resources/PostSaveNodeDocumentResource.java <==
package io.intino.goros.unit.box.rest.resources;

import java.util.List;
import java.util.ArrayList;
import io.intino.alexandria.exceptions.*;
import io.intino.goros.unit.box.*;
import io.intino.alexandria.core.Box;
import io.intino.alexandria.rest.*;
import io.intino.alexandria.http.spark.SparkManager;
import io.intino.alexandria.http.spark.SparkPushService;



public class PostSaveNodeDocumentResource implements Resource {

	private UnitBox box;
	private SparkManager<SparkPushService> manager;

	public PostSaveNodeDocumentResource(UnitBox box, SparkManager manager) {
		this.box = box;
		this.manager = manager;
	}

	public void execute() throws AlexandriaException {
		write(fill(new io.intino.goros.unit.box.actions.PostSaveNodeDocumentAction()).execute());
	}

	private io.intino.goros.unit.box.actions.PostSaveNodeDocumentAction fill(io.intino.goros.unit.box.actions.PostSaveNodeDocumentAction action) {
		action.box = this.box;
		action.context = context();
		action.id = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("id"), String.class);
		action.data = manager.fromPartAsResource("data");
		action.contenttype = io.intino.alexandria.rest.RequestAdapter.adapt(manager.fromQuery("contenttype"), String.class);
		return action;
	}

	private void write(String object) {
		manager.write(io.intino.alexandria.rest.ResponseAdapter.adapt(object));
	}

	private io.intino.alexandria.http.spark.SparkContext context() {
		io.intino.alexandria.http.spark.SparkContext context = new io.intino.alexandria.http.spark.SparkContext(manager);

		context.put("ip", manager.ip());
		return context;
	}
}
